#! /bin/sh

### Richscrips Installer ######################################################
#                                                                             #
#  Type the following command as root.                                        #
#  "sh install.sh"                                                            #
#                                                                             #
###############################################################################


# =============================================================================
# Make sure some conditions
# -----------------------------------------------------------------------------
#  1. Am I root?
#  2. executed in the same path
#  3. OS type
#  4. djbdns ready?
# =============================================================================
#
# --- 1. Am I root? -----
check=`whoami`
if [ "$check" != "root" ]; then
  echo "This script must be executed as root."
  exit 1
fi
# --- 2. executed in the same path -----
if [ \( "$0" != "${0##*/}" \) -a \( "${0##*/}" != "${0##./}" \) ]; then
 echo "Do not execute with absolute path or in a diffrent directory."
 echo "You may type \"sh ${0##*/}\" or \"./${0##*/}\"."
 exit 1
fi
# --- 3. OS type -----
os_type=`uname`
case $os_type in
  FreeBSD)
    ;;
  *)
    echo "Sorry, not supported operating system"
    exit 1
    ;;
 esac
# --- 4. djbdns ready? -----
check=""
if [ \( -n "`which dnscache      2>/dev/null`" \) -a \
     \( -n "`which dnscache-conf 2>/dev/null`" \)   ]; then
  check="OK"
fi
if [ "$check" != "OK" ]; then
  echo "djbdns is not installed."
  echo "You have to install it first."
  exit 1
fi


# =============================================================================
# Ask some questions
# -----------------------------------------------------------------------------
#  1. connection envioronment
#  2. dhclient.conf path
#  3. IIJ-base PPP configuration files path
#  4. MPD5 configuration files path
# =============================================================================
#
# --- 1. connection environment -----
check=""
while [ -z "$connection_env" ]; do
  echo "Choose your connecting tool from the following."
  echo "  1. Using \"dhclient\" to assign an IP address"
  echo "  2. Using \"user-ppp\"(IIJ-PPP) to assign an IP address"
  echo "  3. Using \"MPD ver5\" to assign an IP address"
  echo "  4. A fixed IP address has been already assigned without PPPoE"
  echo "  :"
  echo "  0. other (no configuration files about this will be install.)"
  echo -n "Input (0-4) ? "
  read check
  case $check in
    0)
      connection_env="NONE"
      ;;
    1)
      connection_env="DHCP"
      ;;
    2)
      connection_env="USER-PPP"
      ;;
    3)
      connection_env="MPD5"
      ;;
    4)
      connection_env="FIXED"
      ;;
    *)
      echo "*** Bad number!"
      ;;
   esac
done
# --- 2. dhclient.conf path -----
if [ $connection_env = "DHCP" ]; then
  check=""
  while [ -z "$dhclient_path" ]; do
    echo "Tell me the path of \"dhclinet.conf\" you use now."
    echo -n "Input (absolute path) ? "
    read check
    if [ \( "$check" = "" \) -o \( "${check%%/*}" != "" \) ]; then
      echo "Specify with absolute path!"
      continue
    fi
    if [ "${check##*/}" = "dhclient.conf" ]; then
      check=${check%/dhclient.conf}
    fi
    check="${check%/}"
    if [ -f "$check/dhclient.conf" ]; then
      [ -z "$check" ] && check="/"
      dhclient_path="$check"
    else
      echo "Not found!"
    fi
  done
fi
# --- 3. user-ppp configuration files path -----
if [ $connection_env = "USER-PPP" ]; then
  check=""
  while [ -z "$ppp_path" ]; do
    echo "Tell me the path of \"ppp\"(user-ppp) configuration files you use now."
    echo -n "Input (absolute path) ? "
    read check
    if [ \( "$check" = "" \) -o \( "${check%%/*}" != "" \) ]; then
      echo "Specify with absolute path!"
      continue
    fi
    check=${check%/}
    if [ "${check##*/}" != "ppp" ]; then
      echo "Not \"ppp\" directory!"
      continue
    fi
    check="${check%/ppp}"
    if [ -d "$check/ppp" ]; then
      [ -z "$check" ] && check="/"
      ppp_path="$check"
    else
      echo "Not found!"
    fi
  done
fi
# --- 4. MPD5 files path -----
mpd5_confdir_path="/usr/local/etc/mpd5"
mpd5_rc_path="/usr/local/etc/rc.d/mpd5"
if [ $connection_env = "MPD5" ]; then
  check=""
  if [ \( -n "`which mpd5 2>/dev/null`" \) -a \
       \( -x "$mpd5_rc_path"            \) -a \
       \( -d "$mpd5_confdir_path"       \)   ]; then
    check="OK"
  fi
  if [ "$check" != "OK" ]; then
    echo "MPD version 5 (mpd5) is not installed."
    echo "You have to install it first."
    exit 1
  fi
fi


# =============================================================================
# Ask other questions
# -----------------------------------------------------------------------------
#  1. want to answer to them?
#  2. tell the other questions if requested
# =============================================================================
#
# --- 1. want to answer to them? -----
check=""
while [ -z "$answer_questions" ]; do
  echo "Do you want to set common_local.lib interactively? (Y/n)"
  echo "When you answer \"Yes\", you have to answer many questions."
  echo "If you want to set common_local.lib by yourself, answer \"No\"."
  echo -n "Input (Y/n) : "
  read check
  case $check in
    [Yy]*)
      answer_questions="yes"
      ;;
    [Nn]*)
      answer_questions="no"
      ;;
    '')
      answer_questions="yes"
      ;;
    *)
      echo "*** Bad answer!"
      ;;
   esac
done
# --- 2. tell the other questions if requested -----
if [ "$answer_questions" = "yes" ]; then
  #
  # 2.1 DNSCACHE
  echo "----------------------------------------------------------------------"
  check=""
  while [ -z "$ans_DIR_DNSCACHE" ]; do
    echo "Where is the dnscache configuration directory?"
    echo -n "Input (default=/var/dnscache) : "
    read check
    case $check in
      '')
        ans_DIR_DNSCACHE="/var/dnscache"
        ;;
      *)
        if [ -d "$check" ]; then
          ans_DIR_DNSCACHE="$check"
        else
          echo "*** Unexistent directory!"
        fi
        ;;
     esac
  done
  #
  # 2.2 ntp.conf
  echo "----------------------------------------------------------------------"
  check=""
  while [ -z "$ans_PATH_NTP_CONF" ]; do
    echo "Where is the ntp.conf?"
    echo -n "Input (default=/etc/ntp.conf) : "
    read check
    case $check in
      '')
        ans_PATH_NTP_CONF="/etc/ntp.conf"
        ;;
      *)
        if [ -f "$check" ]; then
          ans_PATH_NTP_CONF="$check"
        else
          echo "*** Unexistent file!"
        fi
        ;;
     esac
  done
  #
  # 2.3 FILE_NS_LIST_FLETS_FWD, ispname1, isp_list, ppp_client, ppp_client
  if [ -n "`echo "$connection_env" | grep '^\(USER-PPP\|MPD5\)$'`" ]; then
    echo "----------------------------------------------------------------------"
    check=""
    while [ -z "$check" ]; do
      echo "Choose the 2nd connecting network (for PPPoE multi session)"
      echo "  1. NTT-East Flet's Square (NOT \"Next\"!)"
      echo "  2. Flet's Info Site"
      echo "     (You must choose it when you use Flet's-Hikari Next of NTT-East.)"
      echo "  3. NTT-East Flet's Square"
      echo "  0. Not to connect Flet's site"
      echo -n "Input (0-3) ? "
      read check
      case $check in
        0)
          ans_FILE_NS_LIST_FLETS_FWD=""
          ans_ispname1=""
          ans_isp_list="0"
          ;;
        1)
          ans_FILE_NS_LIST_FLETS_FWD="flets"
          ans_ispname1="flets_sq_e"
          ans_isp_list="0 1"
          ;;
        2)
          ans_FILE_NS_LIST_FLETS_FWD="v4flets-east.jp"
          ans_ispname1="v4flets_e"
          ans_isp_list="0 1"
          ;;
        3)
          ans_FILE_NS_LIST_FLETS_FWD="flets"
          ans_ispname1="flets_sq_w"
          ans_isp_list="0 1"
          ;;
        *)
          echo "*** Bad number!"
          check=""
          ;;
       esac
    done
    if [ "$connection_env" = "USER-PPP" ]; then
      ans_ppp_client="user-ppp"
    else
      ans_ppp_client="mpd5"
    fi
  else
    ans_FILE_NS_LIST_FLETS_FWD=""
    ans_ispname1=""
    ans_isp_list=""
    ans_ppp_client=""
  fi
  #
  # 2.4 outside network settings
  if   [ "$connection_env" = "USER-PPP" ]; then
    ans_oif="tun0"
  elif [ "$connection_env" = "MPD5"     ]; then
    ans_oif="ng0"
  else
    ans_oif=""
  fi
  echo "----------------------------------------------------------------------"
  if [ -z "$ans_oif" ]; then
    while [ -z "$ans_oif" ]; do
      echo "Which is the interface name for the outside?"
      ifname_list="`ifconfig | grep '^[a-z]\+[0-9]\?:' | awk -F ':' '{print $1}' | grep -v '^\(lo\|pflog\|ipfw\)'`"
      echo -n "  ("
      for ifname in $ifname_list; do
        echo -n " $ifname"
      done
      echo " )"
      echo -n "Input : "
      read check
      for ifname in $ifname_list; do
        if [ "_$check" = "_$ifname" ]; then
          ans_oif="$check"
          break
        fi
      done
      if [ -z "$ans_oif" ]; then
        echo "*** Bad interface name (choose one of the above names)"
      fi
    done
  else
    ans_pppoeif=""
    while [ -z "$ans_pppoeif" ]; do
      echo "Which is the interface name that $connection_env program will use?"
      ifname_list="`ifconfig | grep '^[a-z]\+[0-9]\?:' | awk -F ':' '{print $1}' | grep -v '^\(lo\|pflog\|ipfw\|tun\|ng\)'`"
      echo -n "  ("
      for ifname in $ifname_list; do
        echo -n " $ifname"
      done
      echo " )"
      echo -n "Input : "
      read check
      for ifname in $ifname_list; do
        if [ "_$check" = "_$ifname" ]; then
          ans_pppoeif="$check"
          break
        fi
      done
      if [ -z "$ans_pppoeif" ]; then
        echo "*** Bad interface name (choose one of the above names)"
      fi
    done
  fi
  echo "----------------------------------------------------------------------"
  check=""
  while [ -z "$check" ]; do
    echo "If you want to set a fixed IP address, set it."
    echo "Or you will be assigned a dynamic IP address, press enter key with no letters."
    echo "(You can set the key word \"DETECT\" for detecting automatically.)"
    echo -n "Input : "
    read check
    case $check in
      '')
        ans_oip=""
        check="OK"
        ;;
      *)
        ans_oip="$check"
        check="OK"
        ;;
     esac
  done
  echo "----------------------------------------------------------------------"
  check=""
  while [ -z "$check" ]; do
    echo "If you want to set a primary DNS server IP address manually, set it."
    echo "Or you will be set it automatically, press enter key with no letters."
    echo -n "Input : "
    read check
    case $check in
      '')
        ans_ons1=""
        check="OK"
        ;;
      *)
        ans_ons1="$check"
        check="OK"
        ;;
     esac
  done
  echo "----------------------------------------------------------------------"
  check=""
  while [ -z "$check" ]; do
    echo "If you want to set a secondary DNS server IP address manually, set it."
    echo "Or you will be set it automatically, press enter key with no letters."
    echo -n "Input : "
    read check
    case $check in
      '')
        ans_ons2=""
        check="OK"
        ;;
      *)
        ans_ons2="$check"
        check="OK"
        ;;
     esac
  done
  #
  # 2.5 inside network settings
  echo "----------------------------------------------------------------------"
  ans_iif=""
  while [ -z "$ans_iif" ]; do
    echo "Which is the interface name for the inside?"
    ifname_list="`ifconfig | grep '^[a-z]\+[0-9]\?:' | awk -F ':' '{print $1}' | grep -v '^\(lo\|pflog\|ipfw\|tun\|ng\)'`"
    echo -n "  ("
    for ifname in $ifname_list; do
      echo -n " $ifname"
    done
    echo " )"
    echo -n "Input : "
    read check
    for ifname in $ifname_list; do
      if [ "_$check" = "_$ifname" ]; then
        ans_iif="$check"
        break
      fi
    done
    if [ -z "$ans_iif" ]; then
      echo "*** Bad interface name (choose one of the above names)"
    fi
  done
  echo "----------------------------------------------------------------------"
  check=""
  while [ -z "$check" ]; do
    echo "What is the inside IP address of this host?"
    echo -n "Input : "
    read check
    case $check in
      '')
        echo "*** IP address is empty!"
        check=""
        ;;
      *)
        ans_iip="$check"
        check="OK"
        ;;
     esac
  done
  echo "----------------------------------------------------------------------"
  check=""
  while [ -z "$check" ]; do
    echo "What is the inside network address?"
    echo -n "Input : "
    read check
    case $check in
      '')
        echo "*** network address is empty!"
        check=""
        ;;
      *)
        ans_inw="$check"
        check="OK"
        ;;
     esac
  done
  echo "----------------------------------------------------------------------"
  ans_inm=""
  while [ -z "$ans_inm" ]; do
    echo "What number is the subnet mask bit for inside networks?"
    echo -n "Input : "
    read check
    if [ -n "`echo "$check" | grep '^[0-9]\+$'`" ]; then
      ans_inm="$check"
    else
      echo "*** Bad number!"
    fi
  done
  #
  # 2.6 "Flet's" network settings
  if   [ "$ans_ppp_client" = "user-ppp" ]; then
    ans_fif="tun1"
  elif [ "$ans_ppp_client" = "mpd5"     ]; then
    ans_fif="ng1"
  else
    ans_fif=""
  fi
  if [ -n "$ans_fif" ]; then
    echo "----------------------------------------------------------------------"
    check=""
    while [ -z "$check" ]; do
      echo "If you want to set a primary DNS server address (for Flet's) manually, set it."
      echo "Or you will be set it automatically, press enter key with no letters."
      echo -n "Input : "
      read check
      case $check in
        '')
          ans_fns1=""
          check="OK"
          ;;
        *)
          ans_fns1="$check"
          check="OK"
          ;;
       esac
    done
    echo "----------------------------------------------------------------------"
    check=""
    while [ -z "$check" ]; do
      echo "If you want to set a secondary DNS server address (for Flet's) manually, set it."
      echo "Or you will be set it automatically, press enter key with no letters."
      echo -n "Input : "
      read check
      case $check in
        '')
          ans_fns2=""
          check="OK"
          ;;
        *)
          ans_fns2="$check"
          check="OK"
          ;;
       esac
    done
  fi
  #
  # 2.7 Firewall
  echo "----------------------------------------------------------------------"
  check=""
  while [ -z "$check" ]; do
    echo "Choose firewall program"
    echo "  1. IPFW"
    echo "  2. PF (Packet Filter)"
    echo "  0. none (set manually)"
    echo -n "Input (0-2) ? "
    read check
    case $check in
      0)
        ans_chosen_fw=""
        check="OK"
        ;;
      1)
        ans_chosen_fw="IPFW"
        check="OK"
        ;;
      2)
        ans_chosen_fw="PF"
        check="OK"
        ;;
      3)
        ans_chosen_fw="IPTABLES"
        check="OK"
        ;;
      *)
        echo "*** Bad number!"
        check=""
        ;;
     esac
  done
  if [ "$ans_chosen_fw" = "IPFW" ]; then
    echo "----------------------------------------------------------------------"
    check=""
    while [ -z "$check" ]; do
      echo "Choose IPFW's rule template"
      echo "  1. dynamic filtering rule"
      echo "  2. static filtering rule"
      echo "  0. none (set manually)"
      echo -n "Input (0-2) ? "
      read check
      case $check in
        0)
          ans_FILE_IPFWRULE=""
          check="OK"
          ;;
        1)
          ans_FILE_IPFWRULE="ipfwrule_dynamic.src"
          check="OK"
          ;;
        2)
          ans_FILE_IPFWRULE="ipfwrule_static.src"
          check="OK"
          ;;
        *)
          echo "*** Bad number!"
          check=""
          ;;
       esac
    done
  else
    ans_FILE_IPFWRULE=""
  fi
fi


# =============================================================================
# Install
# -----------------------------------------------------------------------------
#  0. definition
#  1. making sure
#  2. make temporary directory
#  3. install the files in "usr_local_richscripts"
#  4. install the files for "dhclient" or "user-ppp" or "MPD ver5"
#  5. install some OS depending files
#  6. delete temporary directory
# =============================================================================
#
# ----- 0. definition -----
rename_as_sample() {
  local srcfile
  srcfile="tmp/richscripts/etc/$1"
  if [ -f $srcfile ]; then
    mv "$srcfile" "${srcfile}.sample"
  fi
}
copy_from_sample_when_unexists() {
  local srcfile
  local dstfile
  srcfile="/usr/local/richscripts/etc/$1.sample"
  dstfile="/usr/local/richscripts/etc/$1"
  if [ ! -f $dstfile ]; then
    cp "$srcfile" "$dstfile"
  fi
}
# ----- 1. making sure -----
echo -n "Push any key to begin to install. (Ctrl+C to abort install)"
read check
# ----- 2. make temporary directory -----
rm -rf tmp > /dev/null 2>&1
mkdir tmp
# ----- 3. install the files in "usr_local_richscripts" -----
cp -R usr_local_richscripts tmp/richscripts
chmod 544 tmp/richscripts/bin/*.sh
chmod 644 tmp/richscripts/etc/*
chmod 444 tmp/richscripts/etc/common_default.lib
rename_as_sample ddnsup.src
rename_as_sample ipfwrule_dynamic.src
rename_as_sample ipfwrule_static.src
rename_as_sample pf.conf.base
rename_as_sample pf_flets.conf.base
rename_as_sample pf_fletsi2net.conf.base
rename_as_sample pf_i2net.conf.base
cp -R tmp/richscripts /usr/local
copy_from_sample_when_unexists ddnsup.src
copy_from_sample_when_unexists ipfwrule_dynamic.src
copy_from_sample_when_unexists ipfwrule_static.src
copy_from_sample_when_unexists pf.conf.base
copy_from_sample_when_unexists pf_flets.conf.base
copy_from_sample_when_unexists pf_fletsi2net.conf.base
copy_from_sample_when_unexists pf_i2net.conf.base
# ----- 4. install the files for "dhclient" or "user-ppp", "mpd5" -----
case $connection_env in
  DHCP)
    cp dhclient/* tmp
    check=`grep "\-x /etc/dhclient-" $dhclient_path/../sbin/dhclient-script`
    if [ -n "$check" ]; then
      chmod u+x tmp/dhclient-*-hooks
    fi
    [ -f $dhclient_path/dhclient-enter-hooks ] && \
    mv $dhclient_path/dhclient-enter-hooks \
    $dhclient_path/dhclient-enter-hooks.bak
    [ -f $dhclient_path/dhclient-exit-hooks ] && \
    mv $dhclient_path/dhclient-exit-hooks \
    $dhclient_path/dhclient-exit-hooks.bak
    cp tmp/dhclient-*-hooks $dhclient_path
    ;;
  USER-PPP)
    cp -R ppp tmp
    chmod 644 tmp/ppp/*
    chmod go-r tmp/ppp/ppp.conf
    if [ -d $ppp_path ]; then
      [ -d $ppp_path/ppp.bak ] && rm -rf $ppp_path/ppp.bak
      mv $ppp_path/ppp $ppp_path/ppp.bak
    fi
    cp -R tmp/ppp $ppp_path
    ;;
  MPD5)
    conf_name="mpd.conf"
    if [ -f "$mpd5_confdir_path/$conf_name" ]; then
      mv "$mpd5_confdir_path/$conf_name" "$mpd5_confdir_path/${conf_name}.bak"
    fi
    cp "mpd5/$conf_name" "$mpd5_confdir_path"
    chmod 600 "$mpd5_confdir_path/$conf_name"
    ;;
  FIXED)
    ;;
  NONE)
    ;;
esac
# ----- 5. install OS depending files -----
if [ -d "$os_type" ]; then
  cp -R $os_type tmp
  case $os_type in
    FreeBSD)
      if [ \( "$connection_env" = "USER-PPP" \) -o \
           \( "$connection_env" = "MPD5" \)       ]; then
        for filename0 in FreeBSD/etc/start_if.eth0 FreeBSD/etc/stop_if.eth0; do
          filename1="${filename0#FreeBSD}"
          cp "$filename0" "$filename1"
          chmod 644 "$filename1"
          ln "$filename1" "${filename1%.*}.$ans_pppoeif"
        done
      fi
      if [ "$ans_chosen_fw" = "IPFW" ]; then
        cp FreeBSD/etc/natd.conf /etc/natd.conf
      fi
      chmod 744 boot/*
      cp boot/boot_luwaiter.sh /usr/local/etc/rc.d/005.luwaiter.sh
      ;;
    Linux)
      chmod 744 boot/*
      cp boot/boot_luwaiter.sh /etc/init.d/luwaiter
      ;;
  esac
fi
# ----- 6. delete temporary directory -----
rm -rf tmp


# =============================================================================
# Create common_cmd.lib and common_local.lib
# -----------------------------------------------------------------------------
#  0. definition
#  1. create common_cmd.lib
#  2. write commands to the common_cmd.lib
#  3. chmod to common_cmd.lib
#  4. create common_local.lib
#  5. chmod to common_local.lib
# =============================================================================
#
# ----- 0. definition -----
make_cmd_var() {
  local output
  local path_cmd
  [ \( -z "$1" \) -o \( -z "$2" \) ] && return 1
  path_cmd=`which $2 2>/dev/null`
  [ -n "${path_cmd%%/*}" ] && path_cmd=""
  output="${1}=\"$path_cmd\""
  echo $output >> $PATH_CMDPATHLIB
}
compile_conf_file() {
  # ----- 1. define -----
  local src_filepath cmp_filepath TAB line
  src_filepath=$1
  cmp_filepath=$2
  # ----- 2. make the compiled file prototype -----
  echo -n > "$cmp_filepath"
  if [ \( ! -f "$cmp_filepath" \) -o \( ! -w "$cmp_filepath" \) ]; then
    echo "Cannot write compiled file" > /dev/stderr
    exit 1;
  fi
  #
  # ----- 3. show help message and exit if the arguments are not enough -----
  TAB=`printf "\t"`
  cat "$src_filepath" \
  | sed "s/'/!REPLACED_SQ_BY_RICHSCRIPTS!/g" \
  | sed "s/\"/!REPLACED_DQ_BY_RICHSCRIPTS!/g" \
  | sed "s/ /!REPLACED_SPACE_BY_RICHSCRIPTS!/g" \
  | sed "s/$TAB/!REPLACED_TAB_BY_RICHSCRIPTS!/g" \
  | sed 's/\\\$/!REPLACED_ESCAPED-DOLLAR_BY_RICHSCRIPTS!/g' \
  | while read line
  do
    line="_!${line}!_"
    eval echo \"$line\" \
    | sed 's/!REPLACED_ESCAPED-DOLLAR_BY_RICHSCRIPTS!/$/g' \
    | sed "s/!REPLACED_TAB_BY_RICHSCRIPTS!/$TAB/g" \
    | sed "s/!REPLACED_SPACE_BY_RICHSCRIPTS!/ /g" \
    | sed "s/!REPLACED_DQ_BY_RICHSCRIPTS!/\"/g" \
    | sed "s/!REPLACED_SQ_BY_RICHSCRIPTS!/'/g" \
    | sed "s/^_!//" \
    | sed "s/\!_$//" \
    >> "$cmp_filepath"
  done
}
PATH_CMDPATHLIB="/usr/local/richscripts/etc/common_cmds.lib"
FILE_COMONLOCALLIB="common_local.lib"
PATH_COMONLOCALPATHLIB="/usr/local/richscripts/etc/$FILE_COMONLOCALLIB"
PATH_COMONLOCALPATHLIBBASE="usr_local_richscripts/etc/${FILE_COMONLOCALLIB}.base"
# ----- 1. create common_cmd.lib -----
echo -n > $PATH_CMDPATHLIB
# ----- 2. write commands to the common_cmd.lib -----
echo "# ----- OS type -----" >> $PATH_CMDPATHLIB
echo "OS_TYPE=\"$os_type\"" >> $PATH_CMDPATHLIB
echo "" >> $PATH_CMDPATHLIB
echo "# ----- general command -----" >> $PATH_CMDPATHLIB
make_cmd_var CMD_AWK      awk
make_cmd_var CMD_CAT      cat
make_cmd_var CMD_DIFF     diff
make_cmd_var CMD_FIND     find
make_cmd_var CMD_GREP     grep
make_cmd_var CMD_IFCONFIG ifconfig
make_cmd_var CMD_KILL     kill
make_cmd_var CMD_LS       ls
make_cmd_var CMD_MKDIR    mkdir
make_cmd_var CMD_MKTEMP   mktemp
make_cmd_var CMD_MV       mv
make_cmd_var CMD_PRINTF   printf
make_cmd_var CMD_PS       ps
make_cmd_var CMD_RM       rm
make_cmd_var CMD_RMDIR    rmdir
make_cmd_var CMD_ROUTE    route
make_cmd_var CMD_SED      sed
make_cmd_var CMD_SLEEP    sleep
make_cmd_var CMD_SORT     sort
make_cmd_var CMD_TOUCH    touch
echo "" >> $PATH_CMDPATHLIB
echo "# ----- Firewall commands -----" >> $PATH_CMDPATHLIB
make_cmd_var CMD_IPFW     ipfw
make_cmd_var CMD_IPTABLES iptables
make_cmd_var CMD_PFCTL    pf
echo "" >> $PATH_CMDPATHLIB
echo "# ----- PPPoE client -----" >> $PATH_CMDPATHLIB
make_cmd_var CMD_MPD5     "$mpd5_rc_path"
make_cmd_var CMD_PPP      ppp
echo "" >> $PATH_CMDPATHLIB
echo "# ----- daemontools -----" >> $PATH_CMDPATHLIB
make_cmd_var CMD_SVC      svc
echo "" >> $PATH_CMDPATHLIB
echo "# ----- FreeBSD commands -----" >> $PATH_CMDPATHLIB
make_cmd_var CMD_RTPRIO   rtprio
# ----- 3. chmod to common_cmd.lib -----
chmod 644 $PATH_CMDPATHLIB
# ----- 4. create common_local.lib -----
if [ "$answer_questions" = "yes" ]; then
  compile_conf_file \
    "$PATH_COMONLOCALPATHLIBBASE" \
    "$PATH_COMONLOCALPATHLIB"
  rm -f "${PATH_COMONLOCALPATHLIB}.base"
else
  mv "${PATH_COMONLOCALPATHLIB}.base" "$PATH_COMONLOCALPATHLIB"
fi
# ----- 5. chmod to common_local.lib -----
chmod 644 $PATH_COMONLOCALPATHLIB



# =============================================================================
# Install completed
# =============================================================================
#
echo "Richscripts has been installed."
echo
echo "**************************"
echo "!!!!! IMPORTANT ToDo !!!!!"
echo "**************************"
echo "Customize the configuration files as needed."
echo "  * /etc/rc.conf"
if [ "$answer_questions" = "yes" ]; then
  echo "    You should add (change if already exists) the following values"
  echo "    to /etc/rc.conf."
  echo "    # =============================="
  if   [ "$ans_chosen_fw" = "IPFW" ]; then
    echo "      firewall_enable=\"YES\""
    echo "      firewall_script=\"/usr/local/richscripts/bin/regfw.sh\""
    echo "      firewall_logging=\"YES\""
    echo "      natd_enable=\"YES\""
    echo "      natd_interface=\"$ans_oif\""
    echo "      natd_program=\"/usr/sbin/rtprio 5 /sbin/natd\""
    echo "      natd_flags=\"-f /etc/natd.conf\""
  elif [ "$ans_chosen_fw" = "PF" ]; then
    echo "      pf_enable=\"NO\" # set no if you use with Richscripts"
    echo "      pf_rules=\"/usr/local/richscripts/etc/pf.conf\""
    echo "      pflog_enable=\"YES\""
    echo "      ftpproxy_enable=\"YES\""
  fi
  if   [ "$connection_env" = "DHCP"     ]; then
    echo "      ifconfig_${ans_oif}=\"DHCP\""
  elif [ "$connection_env" = "USER-PPP" ]; then
    echo "      ppp_enable=\"NO\" # set no if you use with Richscripts"
    echo "      ppp_nat=\"YES\"
  elif [ "$connection_env" = "MPD5"     ]; then
    echo "      mpd_enable=\"NO\" # set no if you use with Richscripts"
  fi
  echo "    # =============================="
fi
if   [ "$connection_env" = "USER-PPP" ]; then
  echo "  * /etc/ppp/ppp.conf"
  echo "    1. set \"${ans_pppoeif}\" as \"set device PPPoE:\" parameter"
  echo "    2. set user-ID as isp's \"set authname\" parameter"
  echo "    3. set password as isp's \"set authkey\" parameter"
elif [ "$connection_env" = "MPD5"     ]; then
  echo "  * /usr/local/etc/mpd5/mpd.conf"
  echo "    1. set user-ID as isp's \"set auth authname\" parameter"
  echo "    2. set password as isp's \"set auth password\" parameter"
  echo "    3. set \"${ans_pppoeif}\" as every \"set pppoe iface\" parameter"
  if [ -n "ans_FILE_NS_LIST_FLETS_FWD" ]; then
    echo "    4. un-comment out \"load $ans_FILE_NS_LIST_FLETS_FWD\" line"
  fi
fi
if [ \( "$answer_questions" = "no" \) -o \( "$ans_chosen_fw" = "IPFW" \) ]; then
  echo "  * /etc/natd.conf"
  echo "    If you want to do port-fowarding, config the file."
fi
echo "  * /usr/local/richscripts/etc/*"
echo "    a. When you want to customize the firewall rule, congif \"*.src\", \"*.base\"."
echo "    b. When you want to customize other settings, congif \"common_local.lib\"."
echo "  and so on ..."
