#! /bin/sh

### Link Up Waiter ############################################################
#                                                                             #
#  Usage : luwaiter.sh {interfacename}                                        #
#                                                                             #
#  (interfacename): Name of the interface for which wait                      #
#                                                                             #
###############################################################################



# =============================================================================
# Definition
# =============================================================================
#
# ----- define common variables and functions -----
. /usr/local/richscripts/etc/common.lib

PATTERN_IPV4_BW_MATCH=${PATTERN_IPV4#^}


# =============================================================================
# Function
# =============================================================================
#
# ----- comfirm linking up -----
# arg   : $1 ... interface name
# result: 0=The specified interface has gotten an IP address.
#         1=The specified interface has not been able to get an IP address.
#         2=The specified interface name is invalid.
confirm_linkingup() {
  local check
  local result          # The result of this function (See the upper)
  local ifconfig_output # STDOUT from ifconfig command
  local inet_status     # 0:"inet" will be not found yet.
                        # 1:"inet" has been found now.
                        # 2:"inet" has been found a loop ago.
  result=1
  ifconfig_output=`$CMD_IFCONFIG $1 2> /dev/null`
  if [ $? -eq 0 ]; then
    inet_status=0
    for check in $ifconfig_output; do
      if [ $inet_status -le 1 ]; then
        if [ $inet_status -eq 0 ]; then
          if [ "${check#inet}" = "$check" ]; then
            continue
          elif [ "${check#inet6}" != "$check" ]; then
            continue
          fi
        fi
        check=`echo $check | $CMD_GREP -E $PATTERN_IPV4_BW_MATCH`
        if [ -n "$check" ]; then
          result=0
          break
        else
          inet_status=`expr $inet_status + 1`
        fi
      else
        result=1
        break
      fi
    done
  else
    result=2
  fi
  return $result
}



# =============================================================================
#                                     Main
# =============================================================================

# =============================================================================
# Parse the arguments
# -----------------------------------------------------------------------------
#  1. parse the argument
#  2. show help message and exit if the arguments are not enough
# =============================================================================
#
# ----- 1. parse the argument -----
if [ -n "$1" ]; then
  trg_if=$1
# ----- 2. show help message and exit if the arguments are not enough -----
else
  echo "Usage : ${0##*/} interface_name"
  echo "- interface_name must be a name of existant network interface"
  exit
fi


# =============================================================================
# main()
# =============================================================================
#
# ----- Wait for inking up until time up -----
echo -n "Waiting for $trg_if's linking up (over $waiting_limit) "
for wait in $waiting_schedule; do
  confirm_linkingup $trg_if
  result=$?
  if [ $result -eq 0 ]; then
    if [ -z "$linkup" ]; then
      linkup="ALREADY"
    else
      linkup="YES"
    fi
    break
  elif [ $result -eq 2 ]; then
    linkup="BAD"
    break
  fi
  echo -n "."
  linkup="WAITING"
  sleep $wait
done
# ----- Return success or not -----
case "$linkup" in
  [Yy][Ee][Ss])
    echo " Linked up!"
    exit 0
    ;;
  [Aa][Ll][Rr][Ee][Aa][Dd][Yy])
    echo "Linked!"
    exit 0
    ;;
  [Bb][Aa][Dd])
    echo " Invalid interface name!"
    exit 1
    ;;
  *)
    echo " Abandoned"
    exit 1
    ;;
esac
