#! /bin/sh

### MPD Link-down Script ######################################################
#                                                                             #
#  Usage : mpdlnkup.sh interface proto local-ip remote-ip \                   #
#          authname peer-address                                              #
#                                                                             #
#  (interface)      : interface name which assigned the new address by PPP    #
#  (proto)          : protocol name ("inet" if IPv4, "inet6" if IPv6)         #
#  (local-ip)       : the localside IP address assigned by PPP                #
#  (remote-ip)      : the opposite IP address assigned by PPP                 #
#  (authname)       : username used by PPP authentication                     #
#  (peer-address)   : peer MAC address argument given by mpd                  #
#                                                                             #
###############################################################################


# =============================================================================
# Definition
# =============================================================================
#
# ----- define common variables and functions -----
. /usr/local/richscripts/etc/common.lib

# =============================================================================
# Parse the arguments
# -----------------------------------------------------------------------------
#  1. parse new IP address, and so on
#  2. show help message and exit if not enough argument
# =============================================================================
#
# ----- 1. parse new IP address, and so on -----
if="$1"
proto="$2"
auth_name="$5"
case "$proto" in
  inet)
    local_ip="$3"
    local_ip=${local_ip%/*}
    remote_ip="$4"
    remote_ip=${remote_ip%/*}
    remote_addr=$6
    ;;
  inet6)
    remote_addr=$6
    ;;
  *)
    remote_addr="BAD_PROTO"
    ;;
esac
# ----- 2. show help message and exit if the arguments are not enough -----
if [ "_$remote_addr" = "_BAD_PROTO" ]; then
  echo "Usage : ${0##*/} interface proto local-ip remote-ip \ "
  echo "        authname peer-address"
  echo " - interface      : interface name which assigned the new address by PPP"
  echo " - proto          : protocol name ("inet" if IPv4, "inet6" if IPv6)"
  echo " - local-ip       : the localside IP address assigned by PPP"
  echo " - remote-ip      : the opposite IP address assigned by PPP"
  echo " - authname       : username used by PPP authentication"
  echo " - peer-address   : peer-address argument given by mpd"
  debug_log "mpdlnkdw.sh: the arguments are invalid"
  exit
fi


# =============================================================================
# Execute the PPP link-down script
# -----------------------------------------------------------------------------
#  1. decide unit number for the PPP link-down script
#  2. execute the PPP link-down script
# =============================================================================
#
# ----- 1. decide unit number -----
check=`echo "_$auth_name" | $CMD_GREP "@$FILE_NS_LIST_FLETS_FWD$"`
unit_num=${if##*[A-Za-z]}
#
# ----- 2. execute the PPP link-down script -----
$PATH_PPPLNKDW -u $unit_num
