#! /bin/sh

### PPP Link-down Script ######################################################
#                                                                             #
#  Usage : ppplnkdw.sh -u unitnum                                             #
#                                                                             #
#  (unitmun)   : PPP tunnel unit number                                       #
#                                                                             #
###############################################################################


# =============================================================================
# Definition
# =============================================================================
#
# ----- define common variables and functions -----
. /usr/local/richscripts/etc/common.lib
ipfile0="$FILE_CURRENT_IP"
ipfile1="$FILE_CURRENT_IP_FLETS"
nsfiles0="$FILE_NS_LIST_DEFAULT"
nsfiles1="$FILE_NS_LIST_FLETS_FWD"
if [ -n "$FILE_NS_LIST_FLETS_REV" ]; then
  nsfiles1="$nsfiles1 $FILE_NS_LIST_FLETS_REV"
fi


# =============================================================================
# Parse the arguments
# -----------------------------------------------------------------------------
#  1. parse unit number
#  2. show help message and exit if not enough argument
#  3. show help message and exit if the arguments are not enough
# =============================================================================
#
# ----- 1. parse unit number -----
unit_num=""
arg_mode=""
for arg in "$@"
do
  case "$arg" in
    -u) # --- Parse option switches
        arg_mode="$arg"
        ;;
    *)  # --- Parse the parameters
        if [ "$arg_mode" = "-u" ]; then
          check=`echo $arg | $CMD_GREP -E [0-9]`
          [ -n "$check" ] && unit_num="$arg"
        fi
        ;;
  esac
done
# ----- 3. show help message and exit if the arguments are not enough -----
if [ -z "$unit_num" ]; then
  echo "Usage : ${0##*/} -u unitnum"
  echo "- unitnum is PPP tunnel number(0-9)."
  debug_log "ppplnkdw.sh: the arguments are not enough"
  exit
fi


# =============================================================================
# Execute operations after PPP link-down
# -----------------------------------------------------------------------------
#  1. Delete the local route
#  2. Delele the current IP address registry (re-register firewall rule)
#  3. Delele the current DNS forwarding servers
# =============================================================================
#
# ----- 1. Delete the local route -----
eval $PATH_LO0ROUTE -delete -f \$ipfile$unit_num
#
# ----- 2. Delele the current IP address registry -----
eval \$PATH_UPDATEIP -i DELETE -f \$ipfile$unit_num
#
# ----- 3. Delele the current DNS forwarding servers -----
eval \$PATH_REGDNS -n DELETE -f \$nsfiles$unit_num
