#! /bin/sh

### PPP Link-up Script ########################################################
#                                                                             #
#  Usage : ppplnkup.sh -u unitnum \                                           #
#          -i ipaddress [-n nameserver1 [nameserver2 ...]] \                  #
#                                                                             #
#  (unitmun)   : PPP tunnel unit number                                       #
#  (ipaddress) : new IP address specified with "x.x.x.x" style                #
#  (nameserver): nameserver specified with "x.x.x.x" style                    #
#                                                                             #
###############################################################################


# =============================================================================
# Definition
# =============================================================================
#
# ----- define common variables and functions -----
. /usr/local/richscripts/etc/common.lib
ipfile0="$FILE_CURRENT_IP"
ipfile1="$FILE_CURRENT_IP_FLETS"
nsfiles0="$FILE_NS_LIST_DEFAULT"
nsfiles1="$FILE_NS_LIST_FLETS_FWD"
if [ -n "$FILE_NS_LIST_FLETS_REV" ]; then
  nsfiles1="$nsfiles1 $FILE_NS_LIST_FLETS_REV"
fi


# =============================================================================
# Parse the arguments
# -----------------------------------------------------------------------------
#  1. parse unit number
#  2. parse new IP address
#  3. parse nameservers
#  4. show help message and exit if not enough argument
# =============================================================================
#
# ----- 1. 2. 3. parse unit number and new IP address, nameservers -----
unit_num=""
new_ip_addr=""
nameservers=""
arg_mode=""
for arg in "$@"
do
  case "$arg" in
    -*) # --- Parse option switches
        arg_mode=""
        for mode in "-u" "-i" "-n"
        do
          if [ "$arg" = "$mode" ]; then
            arg_mode="$arg"
            break
          fi
        done
        ;;
    *)  # --- Parse the parameters
        if [ "$arg_mode" = "-u" ]; then
          check=`echo $arg | $CMD_GREP -E [0-9]`
          [ -n "$check" ] && unit_num="$arg"
        elif [ "$arg_mode" = "-i" ]; then
          check=`echo $arg | $CMD_GREP -E $PATTERN_IPV4`
          [ -n "$check" ] && new_ip_addr="$arg"
        elif [ "$arg_mode" = "-n" ]; then
          # --- Register in nameserver list only when valid IP address
          check=`echo $arg | $CMD_GREP -E $PATTERN_IPV4`
          if [ -n "$check" ]; then
            if [ "$nameservers" = "" ]; then
              nameservers="$arg"
            else
              nameservers="$nameservers $arg"
            fi
          fi
        fi
        ;;
  esac
done
# ----- 4. show help message and exit if the arguments are not enough -----
if [ \( -z "$unit_num" \) -o \( -z "$new_ip_addr" \) ]; then
  echo "Usage : ${0##*/} -u unitnum -i ipaddress [-n nameserver1 [nameserver2 ...]]"
  echo "- ipaddress and nameserver must be the x.x.x.x style."
  echo "- unitnum is PPP tunnel number(0-9)."
  debug_log "ppplnkup.sh: the arguments are not enough"
  exit
fi


# =============================================================================
# Execute operations after PPP link-up
# -----------------------------------------------------------------------------
#  1. Add the local route
#  2. Register new IP address (re-register firewall rule)
#  3. Register DNS forwarding servers (if required)
# =============================================================================
#
# ----- 1. Add the local route -----
$PATH_LO0ROUTE -add -i $new_ip_addr
#
# ----- 2. Register new IP address -----
eval \$PATH_UPDATEIP -i \$new_ip_addr -f \$ipfile$unit_num
#
# ----- 3. Register DNS forwarding servers if required -----
if [ -n "$nameservers" ]; then
  eval \$PATH_REGDNS -n \$nameservers -f \$nsfiles$unit_num
fi
