#! /bin/sh

### DDNS Updateing Script #####################################################
#                                                                             #
#  Usage : regddns.sh [{-i | -oip} ipaddress]                                 #
#                                                                             #
#  (ipaddress): new IP address                                                #
#                                                                             #
###############################################################################


# =============================================================================
# Definition
# =============================================================================
#
# ----- define common variables and functions -----
. /usr/local/richscripts/etc/common.lib


# =============================================================================
# Start of "breakdown"
# =============================================================================
#
star_of_breakdown="YES"
while [ -n "$star_of_breakdown" ]; do
star_of_breakdown=""


# =============================================================================
# Parse the arguments
# -----------------------------------------------------------------------------
#  1. parse the new IP address
#  2. show help message and exit if not enough argument
# =============================================================================
#
# ----- 1. parse ipaddress -----
arg_switch=""
for arg in "$@"
do
  if [ "$arg_switch" = "" ]; then
    arg_switch="$arg"
  elif [ \( "$arg_switch" = "-oip" \) -o \( "$arg_switch" = "-i" \) ]; then
    arg_switch=""
    oip="$arg"
  fi
done
if [ -z "$oip" ]; then
  if [ -f "$PATH_CURRENT_IP" ]; then
    for oip in `$CMD_CAT $PATH_CURRENT_IP`; do
      break
    done
  fi
fi
# ----- 2. show help message and exit if not enough argument -----
check=`echo $oip | $CMD_GREP -E $PATTERN_IPV4`
if [ -z "$check" ]; then
  echo "DDNS cannot be updated! (Specify the outside I/F's IP address)"
  debug_log "regddns.sh: no outside I/F's IP address specified"
  break
fi


# =============================================================================
# Re-register firewall rule
# -----------------------------------------------------------------------------
# =============================================================================
#
# ----- 0. definition -----
exec_ddns_script() {
  local retry
  retry=3
  while [ $retry -gt 0 ]; do
    $CMD_SLEEP 1
    echo > /dev/null  # for clear "$?"
    . $PATH_DDNSUP
    if [ $? -eq 0 ]; then
      break
    fi
    retry=`expr $retry - 1`
  done
}
# ----- 1. check the IP address -----
check=""
case $oip in
  10.*)
    check="PRIVATEADDRESS"
    ;;
  172.1[6-9].*)
    check="PRIVATEADDRESS"
    ;;
  172.2[0-9].*)
    check="PRIVATEADDRESS"
    ;;
  172.3[01].*)
    check="PRIVATEADDRESS"
    ;;
  192.168.*)
    check="PRIVATEADDRESS"
    ;;
  *)
    if [ -f "$PATH_DDNSUP" ]; then
      exec_ddns_script
      check="DONE"
    else
      check="NOFILE"
    fi
    ;;
esac
# ----- 2. show help message and exit if update faiure -----
if [ "$check" = "PRIVATEADDRESS" ]; then
  echo "DDNS cannot be updated! (Specified IP address is not public one.)"
  debug_log "regddns.sh: outside I/F's is not a public IP address"
  break
fi


# =============================================================================
# End of "breakdown"
# =============================================================================
#
done
